summaryrefslogtreecommitdiff
path: root/TAO/TAO_IDL/be/be_visitor_operation
diff options
context:
space:
mode:
authorokellogg <okellogg@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2002-01-29 20:21:11 +0000
committerokellogg <okellogg@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2002-01-29 20:21:11 +0000
commit15f9b16afed320b4e581b8f61fee7d7fbf1aa9a8 (patch)
treefd798ba5478a08b4b6f842cb8515ed9776861f5f /TAO/TAO_IDL/be/be_visitor_operation
parent5e12d6686388ccadee1714b94ddee0cce6587bfd (diff)
downloadATCD-15f9b16afed320b4e581b8f61fee7d7fbf1aa9a8.tar.gz
ChangeLogTag:Tue Jan 29 21:09:12 2002 Oliver Kellogg <oliver.kellogg@sysde.eads.net>
Diffstat (limited to 'TAO/TAO_IDL/be/be_visitor_operation')
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/amh_sh.cpp8
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/amh_ss.cpp10
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/ami_cs.cpp8
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/ami_exception_holder_operation_cs.cpp4
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/ami_handler_reply_stub_operation_ch.cpp2
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/ami_handler_reply_stub_operation_cs.cpp8
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/argument.cpp8
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/interceptors_arglist.cpp8
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/interceptors_cs.cpp20
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/interceptors_ss.cpp30
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/operation.cpp8
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/operation_cs.cpp4
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/operation_sh.cpp2
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/operation_ss.cpp10
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/remote_proxy_impl_cs.cpp26
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/thru_poa_collocated_ss.cpp2
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/thru_poa_proxy_impl_ss.cpp2
17 files changed, 80 insertions, 80 deletions
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/amh_sh.cpp b/TAO/TAO_IDL/be/be_visitor_operation/amh_sh.cpp
index 2b53e07ae24..3df34d98d0d 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/amh_sh.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/amh_sh.cpp
@@ -84,7 +84,7 @@ be_visitor_amh_operation_sh::visit_operation (be_operation *node)
}
*os << be_nl;
}
- *os << "TAO_ENV_ARG_DECL"
+ *os << "ACE_ENV_ARG_DECL"
<< be_uidt_nl << ")" << be_uidt;
if (be_global->use_raw_throw ())
@@ -116,7 +116,7 @@ be_visitor_amh_operation_sh::visit_attribute (be_attribute *node)
if (!be_global->exception_support ())
{
- *os << "TAO_ENV_SINGLE_ARG_DECL";
+ *os << "ACE_ENV_SINGLE_ARG_DECL";
}
*os << be_uidt_nl << ")" << be_uidt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException)) = 0;\n" << be_nl;
@@ -141,7 +141,7 @@ be_visitor_amh_operation_sh::visit_attribute (be_attribute *node)
if (!be_global->exception_support ())
{
- *os << be_nl << "TAO_ENV_SINGLE_ARG_DECL";
+ *os << be_nl << "ACE_ENV_SINGLE_ARG_DECL";
}
*os << be_uidt_nl << ")" << be_uidt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException)) = 0;\n" << be_nl;
@@ -164,7 +164,7 @@ be_visitor_amh_operation_sh::generate_shared_prologue (be_decl *node,
<< "TAO_ServerRequest &_tao_req," << be_nl
<< "void *_tao_obj," << be_nl
<< "void *_tao_servant_upcall" << be_nl
- << "TAO_ENV_ARG_DECL" << be_uidt_nl
+ << "ACE_ENV_ARG_DECL" << be_uidt_nl
<< ");" << be_uidt << "\n\n";
// We need the interface node in which this operation was defined. However,
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/ami_exception_holder_operation_cs.cpp b/TAO/TAO_IDL/be/be_visitor_operation/ami_exception_holder_operation_cs.cpp
index 7515239ac77..8bf51c89647 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/ami_exception_holder_operation_cs.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/ami_exception_holder_operation_cs.cpp
@@ -104,7 +104,7 @@ be_visitor_operation_ami_exception_holder_operation_cs::visit_operation (be_oper
*os << node->local_name () << "(";
if (!be_global->exception_support ())
- *os << "TAO_ENV_SINGLE_ARG_DECL";
+ *os << "ACE_ENV_SINGLE_ARG_DECL";
*os << ")" << be_uidt;
@@ -176,7 +176,7 @@ be_visitor_operation_ami_exception_holder_operation_cs::visit_operation (be_oper
<< "this->marshaled_exception ().length ()," << be_nl
<< "this->byte_order ()," << be_nl
<< "this->is_system_exception ()" << be_nl
- << "TAO_ENV_ARG_PARAMETER);" << be_uidt << be_uidt_nl;
+ << "ACE_ENV_ARG_PARAMETER);" << be_uidt << be_uidt_nl;
*os << "}\n\n";
return 0;
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/ami_handler_reply_stub_operation_ch.cpp b/TAO/TAO_IDL/be/be_visitor_operation/ami_handler_reply_stub_operation_ch.cpp
index e5a8b2c763a..64ed89f8ce9 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/ami_handler_reply_stub_operation_ch.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/ami_handler_reply_stub_operation_ch.cpp
@@ -80,7 +80,7 @@ be_visitor_operation_ami_handler_reply_stub_operation_ch::visit_operation (be_op
<< "CORBA::ULong reply_status";
*os << be_nl
- << "TAO_ENV_ARG_DECL_WITH_DEFAULTS" << be_uidt_nl
+ << "ACE_ENV_ARG_DECL_WITH_DEFAULTS" << be_uidt_nl
<< ");" << be_uidt_nl << be_nl;
}
return 0;
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/argument.cpp b/TAO/TAO_IDL/be/be_visitor_operation/argument.cpp
index 0b5b69678dd..79fe13e262c 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/argument.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/argument.cpp
@@ -85,7 +85,7 @@ be_visitor_operation_argument::visit_operation (be_operation *node)
}
// if we are supporting the alternate mapping, we must pass the
- // TAO_ENV_ARG_PARAMETER as the last parameter
+ // ACE_ENV_ARG_PARAMETER as the last parameter
if (!be_global->exception_support ())
{
switch (this->ctx_->state ())
@@ -94,12 +94,12 @@ be_visitor_operation_argument::visit_operation (be_operation *node)
case TAO_CodeGen::TAO_OPERATION_COLLOCATED_ARG_UPCALL_SS:
// applicable only to these cases where the actual upcall is made
- // Use TAO_ENV_SINGLE_ARG_DECL or TAO_ENV_ARG_DECL depending on
+ // Use ACE_ENV_SINGLE_ARG_DECL or ACE_ENV_ARG_DECL depending on
// whether the operation node has parameters.
if (node->argument_count () > 0)
- *os << " TAO_ENV_ARG_PARAMETER";
+ *os << " ACE_ENV_ARG_PARAMETER";
else
- *os << "TAO_ENV_SINGLE_ARG_PARAMETER";
+ *os << "ACE_ENV_SINGLE_ARG_PARAMETER";
break;
default:
break;
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/interceptors_arglist.cpp b/TAO/TAO_IDL/be/be_visitor_operation/interceptors_arglist.cpp
index 27fc52b8574..27499952058 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/interceptors_arglist.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/interceptors_arglist.cpp
@@ -58,7 +58,7 @@ be_visitor_operation_interceptors_arglist::visit_operation (be_operation *node)
-1);
}
- // generate the TAO_ENV_ARG_PARAMETER for the alternative mapping
+ // generate the ACE_ENV_ARG_PARAMETER for the alternative mapping
if (!be_global->exception_support ())
{
switch (this->ctx_->state ())
@@ -73,14 +73,14 @@ be_visitor_operation_interceptors_arglist::visit_operation (be_operation *node)
case TAO_CodeGen::TAO_OPERATION_INTERCEPTORS_INFO_ARGLIST_CS:
case TAO_CodeGen::TAO_OPERATION_INTERCEPTORS_INFO_ARGLIST_SS:
{
- *os << " TAO_ENV_ARG_PARAMETER";
+ *os << " ACE_ENV_ARG_PARAMETER";
break;
}
case TAO_CodeGen::TAO_OPERATION_INTERCEPTORS_ARGLIST_CS:
case TAO_CodeGen::TAO_OPERATION_INTERCEPTORS_ARGLIST_SS:
{
// last argument - is always CORBA::Environment
- *os << " TAO_ENV_ARG_DECL_NOT_USED";
+ *os << " ACE_ENV_ARG_DECL_NOT_USED";
break;
}
case TAO_CodeGen::TAO_OPERATION_INTERCEPTORS_ARGLIST_CH:
@@ -89,7 +89,7 @@ be_visitor_operation_interceptors_arglist::visit_operation (be_operation *node)
// @@ Do it for all cases i.e arg count > = 0
// last argument - is always CORBA::Environment
- *os << " TAO_ENV_ARG_DECL_WITH_DEFAULTS" << be_uidt_nl;
+ *os << " ACE_ENV_ARG_DECL_WITH_DEFAULTS" << be_uidt_nl;
break;
}
default:
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/interceptors_cs.cpp b/TAO/TAO_IDL/be/be_visitor_operation/interceptors_cs.cpp
index 2979bc2edc5..122e9f3784c 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/interceptors_cs.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/interceptors_cs.cpp
@@ -185,17 +185,17 @@ be_visitor_operation_interceptors_cs::
// Here I still need to generate the other methods + private args.
*os << "virtual Dynamic::ParameterList * arguments "
- << "(TAO_ENV_SINGLE_ARG_DECL)" << be_idt_nl
+ << "(ACE_ENV_SINGLE_ARG_DECL)" << be_idt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException));"
<< be_uidt_nl << be_nl;
*os << "virtual Dynamic::ExceptionList * exceptions "
- << "(TAO_ENV_SINGLE_ARG_DECL)" << be_idt_nl
+ << "(ACE_ENV_SINGLE_ARG_DECL)" << be_idt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException));"
<< be_uidt_nl << be_nl;
*os << "virtual CORBA::Any * result "
- << "(TAO_ENV_SINGLE_ARG_DECL)" << be_idt_nl
+ << "(ACE_ENV_SINGLE_ARG_DECL)" << be_idt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException));\n"
<< be_uidt;
@@ -574,7 +574,7 @@ be_visitor_operation_interceptors_cs::
}
}
- *os << "::arguments (TAO_ENV_SINGLE_ARG_DECL)" << be_idt_nl
+ *os << "::arguments (ACE_ENV_SINGLE_ARG_DECL)" << be_idt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException))"<< be_uidt_nl
<< "{" << be_idt_nl;
@@ -582,7 +582,7 @@ be_visitor_operation_interceptors_cs::
{
*os << "// Generate the argument list on demand." << be_nl
<< "Dynamic::ParameterList *parameter_list =" << be_idt_nl
- << "TAO_RequestInfo_Util::make_parameter_list (TAO_ENV_SINGLE_ARG_PARAMETER);"
+ << "TAO_RequestInfo_Util::make_parameter_list (ACE_ENV_SINGLE_ARG_PARAMETER);"
<< be_uidt_nl
<< "ACE_CHECK_RETURN (0);" << be_nl
<< be_nl;
@@ -693,7 +693,7 @@ be_visitor_operation_interceptors_cs::
}
}
- *os << "::exceptions (TAO_ENV_SINGLE_ARG_DECL)"<< be_idt_nl
+ *os << "::exceptions (ACE_ENV_SINGLE_ARG_DECL)"<< be_idt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException))" << be_uidt_nl
<< "{" << be_idt_nl;
@@ -701,7 +701,7 @@ be_visitor_operation_interceptors_cs::
{
*os << "// Generate the exception list on demand." << be_nl
<< "Dynamic::ExceptionList *exception_list =" << be_idt_nl
- << "TAO_RequestInfo_Util::make_exception_list (TAO_ENV_SINGLE_ARG_PARAMETER);"
+ << "TAO_RequestInfo_Util::make_exception_list (ACE_ENV_SINGLE_ARG_PARAMETER);"
<< be_uidt_nl
<< "ACE_CHECK_RETURN (0);" << be_nl
<< be_nl;
@@ -790,7 +790,7 @@ be_visitor_operation_interceptors_cs::
}
}
- *os << "::result (TAO_ENV_SINGLE_ARG_DECL)" << be_idt_nl
+ *os << "::result (ACE_ENV_SINGLE_ARG_DECL)" << be_idt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException))" << be_uidt_nl
<< "{" << be_idt_nl;
@@ -805,7 +805,7 @@ be_visitor_operation_interceptors_cs::
// Return an Any with tk_void TypeCode.
*os << "CORBA::Boolean tk_void_any = 1;" << be_nl
<< "CORBA::Any *result_any =" << be_idt_nl
- << "TAO_RequestInfo_Util::make_any (tk_void_any TAO_ENV_ARG_PARAMETER);"
+ << "TAO_RequestInfo_Util::make_any (tk_void_any ACE_ENV_ARG_PARAMETER);"
<< be_uidt_nl
<< "ACE_CHECK_RETURN (0);" << be_nl
<< be_nl
@@ -815,7 +815,7 @@ be_visitor_operation_interceptors_cs::
{
*os << "CORBA::Boolean tk_void_any = 0;" << be_nl
<< "CORBA::Any *result_any =" << be_idt_nl
- << "TAO_RequestInfo_Util::make_any (tk_void_any TAO_ENV_ARG_PARAMETER);"
+ << "TAO_RequestInfo_Util::make_any (tk_void_any ACE_ENV_ARG_PARAMETER);"
<< be_uidt_nl
<< "ACE_CHECK_RETURN (0);" << be_nl
<< be_nl
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/interceptors_ss.cpp b/TAO/TAO_IDL/be/be_visitor_operation/interceptors_ss.cpp
index 0b141fb00f6..d651e62e77f 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/interceptors_ss.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/interceptors_ss.cpp
@@ -199,35 +199,35 @@ be_visitor_operation_interceptors_ss::
// Here I still need to generate the other methods + private args
*os << "virtual Dynamic::ParameterList * arguments ("
<< be_idt << be_idt_nl
- << "TAO_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS" << be_uidt_nl
+ << "ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS" << be_uidt_nl
<< ")" << be_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException));"
<< be_uidt_nl << be_nl;
*os << "virtual Dynamic::ExceptionList * exceptions ("
<< be_idt << be_idt_nl
- << "TAO_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS" << be_uidt_nl
+ << "ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS" << be_uidt_nl
<< ")" << be_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException));"
<< be_uidt_nl << be_nl;
*os << "virtual CORBA::Any * result ("
<< be_idt << be_idt_nl
- << "TAO_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS" << be_uidt_nl
+ << "ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS" << be_uidt_nl
<< ")" << be_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException));"
<< be_uidt_nl << be_nl;
*os << "virtual char * target_most_derived_interface ("
<< be_idt << be_idt_nl
- << "TAO_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)"
+ << "ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)"
<< be_uidt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException));"
<< be_uidt_nl << be_nl;
*os << "virtual CORBA::Boolean target_is_a (" << be_idt << be_idt_nl
<< "const char * id" << be_nl
- << "TAO_ENV_ARG_DECL_WITH_DEFAULTS)"
+ << "ACE_ENV_ARG_DECL_WITH_DEFAULTS)"
<< be_uidt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException));\n"
<< be_uidt_nl;
@@ -635,12 +635,12 @@ be_visitor_operation_interceptors_ss::
}
}
- *os << "::arguments (TAO_ENV_SINGLE_ARG_DECL)" << be_idt_nl
+ *os << "::arguments (ACE_ENV_SINGLE_ARG_DECL)" << be_idt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException))" << be_uidt_nl
<< "{" << be_idt_nl
<< "// Generate the argument list on demand." << be_nl
<< "Dynamic::ParameterList *parameter_list =" << be_idt_nl
- << "TAO_RequestInfo_Util::make_parameter_list (TAO_ENV_SINGLE_ARG_PARAMETER);"
+ << "TAO_RequestInfo_Util::make_parameter_list (ACE_ENV_SINGLE_ARG_PARAMETER);"
<< be_uidt_nl
<< "ACE_CHECK_RETURN (0);" << be_nl
<< be_nl;
@@ -737,7 +737,7 @@ be_visitor_operation_interceptors_ss::
}
}
- *os << "::exceptions (TAO_ENV_SINGLE_ARG_DECL)"<< be_idt_nl
+ *os << "::exceptions (ACE_ENV_SINGLE_ARG_DECL)"<< be_idt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException))" << be_uidt_nl
<< "{" << be_idt_nl;
@@ -745,7 +745,7 @@ be_visitor_operation_interceptors_ss::
{
*os << "// Generate the exception list on demand." << be_nl
<< "Dynamic::ExceptionList *exception_list =" << be_idt_nl
- << "TAO_RequestInfo_Util::make_exception_list (TAO_ENV_SINGLE_ARG_PARAMETER);"
+ << "TAO_RequestInfo_Util::make_exception_list (ACE_ENV_SINGLE_ARG_PARAMETER);"
<< be_uidt_nl
<< "ACE_CHECK_RETURN (0);" << be_nl
<< be_nl;
@@ -834,7 +834,7 @@ be_visitor_operation_interceptors_ss::
}
}
- *os << "::result (TAO_ENV_SINGLE_ARG_DECL)"<< be_idt_nl
+ *os << "::result (ACE_ENV_SINGLE_ARG_DECL)"<< be_idt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException))" << be_uidt_nl
<< "{" << be_idt_nl;
@@ -849,7 +849,7 @@ be_visitor_operation_interceptors_ss::
// Return an Any with tk_void TypeCode.
*os << "CORBA::Boolean tk_void_any = 1;" << be_nl
<< "CORBA::Any *result_any =" << be_idt_nl
- << "TAO_RequestInfo_Util::make_any (tk_void_any TAO_ENV_ARG_PARAMETER);"
+ << "TAO_RequestInfo_Util::make_any (tk_void_any ACE_ENV_ARG_PARAMETER);"
<< be_uidt_nl
<< "ACE_CHECK_RETURN (0);" << be_nl
<< be_nl
@@ -859,7 +859,7 @@ be_visitor_operation_interceptors_ss::
{
*os << "CORBA::Boolean tk_void_any = 0;" << be_nl
<< "CORBA::Any *result_any =" << be_idt_nl
- << "TAO_RequestInfo_Util::make_any (tk_void_any TAO_ENV_ARG_PARAMETER);"
+ << "TAO_RequestInfo_Util::make_any (tk_void_any ACE_ENV_ARG_PARAMETER);"
<< be_uidt_nl
<< "ACE_CHECK_RETURN (0);" << be_nl
<< be_nl
@@ -941,7 +941,7 @@ be_visitor_operation_interceptors_ss::
*os << "::target_most_derived_interface ("
<< be_idt << be_idt_nl
- << "TAO_ENV_SINGLE_ARG_DECL_NOT_USED)" << be_uidt_nl
+ << "ACE_ENV_SINGLE_ARG_DECL_NOT_USED)" << be_uidt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException))" << be_uidt_nl
<< "{" << be_idt_nl
<< "return" << be_idt_nl
@@ -987,10 +987,10 @@ be_visitor_operation_interceptors_ss::
*os << "::target_is_a (" << be_idt << be_idt_nl
<< "const char * id" << be_nl
- << "TAO_ENV_ARG_DECL)" << be_uidt_nl
+ << "ACE_ENV_ARG_DECL)" << be_uidt_nl
<< "ACE_THROW_SPEC ((CORBA::SystemException))" << be_uidt_nl
<< "{" << be_idt_nl
- << "return this->_tao_impl->_is_a (id TAO_ENV_ARG_PARAMETER);"
+ << "return this->_tao_impl->_is_a (id ACE_ENV_ARG_PARAMETER);"
<< be_uidt_nl << "}" << be_nl << be_nl;
// -----------------------------------------------------------------
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/operation_cs.cpp b/TAO/TAO_IDL/be/be_visitor_operation/operation_cs.cpp
index 829cf9a36b7..7b3d8a12ab8 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/operation_cs.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/operation_cs.cpp
@@ -171,7 +171,7 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
*os << intf->base_proxy_impl_name () << " &proxy = " << be_idt_nl
<< "this->the" << intf->base_proxy_broker_name ()
- << "_->select_proxy (this TAO_ENV_ARG_PARAMETER);" << be_uidt_nl;
+ << "_->select_proxy (this ACE_ENV_ARG_PARAMETER);" << be_uidt_nl;
if (!this->void_return_type (bt))
{
@@ -249,7 +249,7 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
if (!be_global->exception_support ())
{
- *os << " TAO_ENV_ARG_PARAMETER";
+ *os << " ACE_ENV_ARG_PARAMETER";
}
*os << be_uidt_nl << ");" << be_uidt << be_uidt_nl << "}\n\n";
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/operation_sh.cpp b/TAO/TAO_IDL/be/be_visitor_operation/operation_sh.cpp
index 0aa4c6c2729..096fc8a6633 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/operation_sh.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/operation_sh.cpp
@@ -138,7 +138,7 @@ be_visitor_operation_sh::visit_operation (be_operation *node)
<< "TAO_ServerRequest &_tao_req," << be_nl
<< "void *_tao_obj," << be_nl
<< "void *_tao_servant_upcall" << be_nl
- << "TAO_ENV_ARG_DECL" << be_uidt_nl
+ << "ACE_ENV_ARG_DECL" << be_uidt_nl
<< ");" << be_uidt << "\n\n";
}
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/operation_ss.cpp b/TAO/TAO_IDL/be/be_visitor_operation/operation_ss.cpp
index 35606d79667..af39de154e1 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/operation_ss.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/operation_ss.cpp
@@ -127,7 +127,7 @@ be_visitor_operation_ss::visit_operation (be_operation *node)
<< "TAO_ServerRequest &_tao_server_request," << be_nl
<< "void *_tao_object_reference," << be_nl
<< "void *_tao_servant_upcall" << be_nl
- << "TAO_ENV_ARG_DECL" << be_uidt_nl
+ << "ACE_ENV_ARG_DECL" << be_uidt_nl
<< ")" << be_uidt_nl;
// Generate the actual code for the skeleton. However, if any of the argument
@@ -295,7 +295,7 @@ be_visitor_operation_ss::visit_operation (be_operation *node)
<< be_nl << be_nl;
// Invoke the receive_request() interception point.
- *os << "_tao_vfr.receive_request (&_tao_ri TAO_ENV_ARG_PARAMETER);" << be_nl
+ *os << "_tao_vfr.receive_request (&_tao_ri ACE_ENV_ARG_PARAMETER);" << be_nl
<< "ACE_TRY_CHECK;" << be_nl;
*os << "\n#endif /* TAO_HAS_INTERCEPTORS */\n";
@@ -404,7 +404,7 @@ be_visitor_operation_ss::visit_operation (be_operation *node)
}
*os << "_tao_ri.reply_status (PortableInterceptor::SUCCESSFUL);" << be_nl
- << "_tao_vfr.send_reply (&_tao_ri TAO_ENV_ARG_PARAMETER);"<< be_nl
+ << "_tao_vfr.send_reply (&_tao_ri ACE_ENV_ARG_PARAMETER);"<< be_nl
<< "ACE_TRY_CHECK;" << be_uidt_nl;
*os << "}" << be_uidt_nl
@@ -414,7 +414,7 @@ be_visitor_operation_ss::visit_operation (be_operation *node)
*os << "_tao_ri.exception (&ACE_ANY_EXCEPTION);"<< be_nl
<< "_tao_vfr.send_exception (" << be_idt << be_idt_nl
<< "&_tao_ri" << be_nl
- << "TAO_ENV_ARG_PARAMETER" << be_uidt_nl
+ << "ACE_ENV_ARG_PARAMETER" << be_uidt_nl
<< ");" << be_uidt_nl
<< "ACE_TRY_CHECK;" << be_nl;
@@ -423,7 +423,7 @@ be_visitor_operation_ss::visit_operation (be_operation *node)
// exception.
*os << be_nl
<< "PortableInterceptor::ReplyStatus _tao_status =" << be_idt_nl
- << "_tao_ri.reply_status (TAO_ENV_SINGLE_ARG_PARAMETER);" << be_uidt_nl
+ << "_tao_ri.reply_status (ACE_ENV_SINGLE_ARG_PARAMETER);" << be_uidt_nl
<< "ACE_TRY_CHECK;" << be_nl;
*os << be_nl
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/thru_poa_collocated_ss.cpp b/TAO/TAO_IDL/be/be_visitor_operation/thru_poa_collocated_ss.cpp
index 2b67da969ad..45a3a6b8d77 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/thru_poa_collocated_ss.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/thru_poa_collocated_ss.cpp
@@ -140,7 +140,7 @@ int be_visitor_operation_thru_poa_collocated_ss::visit_operation (be_operation *
<< "\"" << node->original_local_name () << "\"," << be_nl
<< "forward_to.out ()";
if (!be_global->exception_support ())
- *os << " TAO_ENV_ARG_PARAMETER);\n" << be_uidt_nl << be_uidt;
+ *os << " ACE_ENV_ARG_PARAMETER);\n" << be_uidt_nl << be_uidt;
else
*os << be_uidt_nl << ");\n" << be_uidt;
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/thru_poa_proxy_impl_ss.cpp b/TAO/TAO_IDL/be/be_visitor_operation/thru_poa_proxy_impl_ss.cpp
index 8d2b61b6eae..84fdaac5823 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/thru_poa_proxy_impl_ss.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/thru_poa_proxy_impl_ss.cpp
@@ -149,7 +149,7 @@ be_visitor_operation_thru_poa_proxy_impl_ss::visit_operation (be_operation *node
<< "forward_to.out ()";
if (!be_global->exception_support ())
*os << be_nl
- << "TAO_ENV_ARG_PARAMETER" << be_uidt_nl
+ << "ACE_ENV_ARG_PARAMETER" << be_uidt_nl
<< ");" << be_nl << be_uidt;
else
*os << be_uidt_nl << ");" << be_uidt_nl;
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/amh_ss.cpp b/TAO/TAO_IDL/be/be_visitor_operation/amh_ss.cpp
index 7b5774e86b8..73a0a577385 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/amh_ss.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/amh_ss.cpp
@@ -153,7 +153,7 @@ be_visitor_amh_operation_ss::visit_operation (be_operation *node)
}
*os << be_nl;
}
- *os << "TAO_ENV_ARG_PARAMETER";
+ *os << "ACE_ENV_ARG_PARAMETER";
}
if (this->generate_shared_epilogue (os) == -1)
@@ -175,7 +175,7 @@ be_visitor_amh_operation_ss::visit_attribute (be_attribute *node)
if (this->generate_shared_section (node, os) == -1)
return -1;
- *os << "TAO_ENV_ARG_PARAMETER";
+ *os << "ACE_ENV_ARG_PARAMETER";
if (this->generate_shared_epilogue (os) == -1)
return -1;
@@ -231,7 +231,7 @@ be_visitor_amh_operation_ss::visit_attribute (be_attribute *node)
return -1;
*os << ", " << node->local_name ()
- << be_nl << "TAO_ENV_ARG_PARAMETER";
+ << be_nl << "ACE_ENV_ARG_PARAMETER";
if (this->generate_shared_epilogue (os) == -1)
return -1;
@@ -278,11 +278,11 @@ be_visitor_amh_operation_ss::generate_shared_prologue (be_decl *node,
<< "TAO_ServerRequest &_tao_server_request," << be_nl
<< "void *_tao_object_reference, " << be_nl
<< "void * /* context */ " << be_nl
- << "TAO_ENV_ARG_DECL" << be_uidt_nl
+ << "ACE_ENV_ARG_DECL" << be_uidt_nl
<< ")" << be_uidt_nl;
// Generate the actual code for the skeleton.
// last argument - is always TAO_ENV_ARG_PARAMETER.
*os << "{" << be_idt_nl;
// Get the right object implementation.
@@ -278,11 +278,11 @@ be_visitor_amh_operation_ss::generate_shared_prologue (be_decl *node,
<< ")" << be_uidt_nl;
// Generate the actual code for the skeleton.
- // last argument - is always TAO_ENV_ARG_PARAMETER.
+ // last argument - is always ACE_ENV_ARG_PARAMETER.
*os << "{" << be_idt_nl;
// Get the right object implementation.
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/ami_cs.cpp b/TAO/TAO_IDL/be/be_visitor_operation/ami_cs.cpp
index 51e3fc4eb7b..a8577a4ac25 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/ami_cs.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/ami_cs.cpp
@@ -120,7 +120,7 @@ be_visitor_operation_ami_cs::visit_operation (be_operation *node)
// Generate the actual code for the stub. However, if any of the argument
// types is "native", we flag a MARSHAL exception.
// last argument - is always TAO_ENV_ARG_PARAMETER
*os << "{" << be_idt_nl;
*os << this->gen_environment_var () << be_nl;
@@ -392,7 +392,7 @@ be_compiled_visitor_operation_ami_cs::gen_marshal_and_invoke (be_operation *node
<< "for (;;)" << be_nl
<< "{" << be_idt_nl;
- *os << "_tao_call.start (TAO_ENV_SINGLE_ARG_PARAMETER);" << be_nl;
+ *os << "_tao_call.start (ACE_ENV_SINGLE_ARG_PARAMETER);" << be_nl;
// Check if there is an exception.
// Return type is void, so we know what to generate here.
*os << "ACE_CHECK;" << be_nl;
@@ -412,7 +412,7 @@ be_compiled_visitor_operation_ami_cs::gen_marshal_and_invoke (be_operation *node
*os << be_nl
<< "_tao_call.prepare_header (" << be_idt << be_idt_nl
- << "ACE_static_cast (CORBA::Octet, _tao_response_flag) TAO_ENV_ARG_PARAMETER"
+ << "ACE_static_cast (CORBA::Octet, _tao_response_flag) ACE_ENV_ARG_PARAMETER"
<< be_uidt_nl << ");" << be_uidt << "\n";
// Now make sure that we have some in and inout
@@ -456,7 +456,7 @@ be_compiled_visitor_operation_ami_cs::gen_marshal_and_invoke (be_operation *node
}
*os << be_nl
- << "int _invoke_status = _tao_call.invoke (TAO_ENV_SINGLE_ARG_PARAMETER);";
+ << "int _invoke_status = _tao_call.invoke (ACE_ENV_SINGLE_ARG_PARAMETER);";
*os << be_uidt_nl;
@@ -120,7 +120,7 @@ be_visitor_operation_ami_cs::visit_operation (be_operation *node)
// Generate the actual code for the stub. However, if any of the argument
// types is "native", we flag a MARSHAL exception.
- // last argument - is always TAO_ENV_ARG_PARAMETER
+ // last argument - is always ACE_ENV_ARG_PARAMETER
*os << "{" << be_idt_nl;
*os << this->gen_environment_var () << be_nl;
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/ami_handler_reply_stub_operation_cs.cpp b/TAO/TAO_IDL/be/be_visitor_operation/ami_handler_reply_stub_operation_cs.cpp
index 599429e8e43..1220c388552 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/ami_handler_reply_stub_operation_cs.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/ami_handler_reply_stub_operation_cs.cpp
@@ -113,13 +113,13 @@ be_visitor_operation_ami_handler_reply_stub_operation_cs::visit_operation (be_op
<< "CORBA::ULong reply_status";
*os << be_nl
- << "TAO_ENV_ARG_DECL";
+ << "ACE_ENV_ARG_DECL";
*os << ")" << be_uidt << be_uidt_nl;
// Generate the actual code for the stub. However, if any of the argument
// types is "native", we flag a MARSHAL exception.
// last argument - is always TAO_ENV_ARG_PARAMETER
*os << "{\n" << be_idt;
// Generate any pre stub info if and only if none of our parameters is of the
@@ -148,7 +148,7 @@ be_visitor_operation_ami_handler_reply_stub_operation_cs::visit_operation (be_op
<< "_tao_reply_handler_object =" << be_idt_nl;
*os << parent->full_name ();
- *os << "::_narrow(_tao_reply_handler TAO_ENV_ARG_PARAMETER);" << be_uidt_nl;
+ *os << "::_narrow(_tao_reply_handler ACE_ENV_ARG_PARAMETER);" << be_uidt_nl;
*os << "ACE_CHECK;" << be_nl << be_nl
<< "// Exception handling" << be_nl
@@ -249,7 +249,7 @@ be_visitor_operation_ami_handler_reply_stub_operation_cs::visit_operation (be_op
if (!be_global->exception_support ())
{
- *os << " TAO_ENV_ARG_PARAMETER";
+ *os << " ACE_ENV_ARG_PARAMETER";
}
*os << be_uidt_nl << ");" << be_uidt_nl;
@@ -113,13 +113,13 @@ be_visitor_operation_ami_handler_reply_stub_operation_cs::visit_operation (be_op
// Generate the actual code for the stub. However, if any of the argument
// types is "native", we flag a MARSHAL exception.
- // last argument - is always TAO_ENV_ARG_PARAMETER
+ // last argument - is always ACE_ENV_ARG_PARAMETER
*os << "{\n" << be_idt;
// Generate any pre stub info if and only if none of our parameters is of the
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/operation.cpp b/TAO/TAO_IDL/be/be_visitor_operation/operation.cpp
index 1a4df226278..05dddecb079 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/operation.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/operation.cpp
@@ -161,11 +161,11 @@ be_visitor_operation::gen_environment_decl (int argument_emitted,
if (be_global->exception_support ())
return 0;
// Use TAO_ENV_SINGLE_ARG_DECL or TAO_ENV_ARG_DECL depending on
// whether the operation node has parameters.
- const char *env_decl = "TAO_ENV_SINGLE_ARG_DECL";
+ const char *env_decl = "ACE_ENV_SINGLE_ARG_DECL";
if (argument_emitted || node->argument_count () > 0)
- env_decl = "TAO_ENV_ARG_DECL";
+ env_decl = "ACE_ENV_ARG_DECL";
*os << be_nl;
switch (this->ctx_->state ())
@@ -180,7 +180,7 @@ be_visitor_operation::gen_environment_decl (int argument_emitted,
case TAO_CodeGen::TAO_OPERATION_ARGLIST_IH:
case TAO_CodeGen::TAO_OPERATION_ARGLIST_PROXY_IMPL_XH:
case TAO_CodeGen::TAO_OPERATION_ARGLIST_BASE_PROXY_IMPL_CH:
// last argument - is always TAO_ENV_ARG_DECL
*os << env_decl;
break;
default:
@@ -161,11 +161,11 @@ be_visitor_operation::gen_environment_decl (int argument_emitted,
if (be_global->exception_support ())
return 0;
- // Use TAO_ENV_SINGLE_ARG_DECL or TAO_ENV_ARG_DECL depending on
+ // Use ACE_ENV_SINGLE_ARG_DECL or ACE_ENV_ARG_DECL depending on
// whether the operation node has parameters.
@@ -180,7 +180,7 @@ be_visitor_operation::gen_environment_decl (int argument_emitted,
case TAO_CodeGen::TAO_OPERATION_ARGLIST_PROXY_IMPL_XH:
case TAO_CodeGen::TAO_OPERATION_ARGLIST_BASE_PROXY_IMPL_CH:
- // last argument - is always TAO_ENV_ARG_DECL
+ // last argument - is always ACE_ENV_ARG_DECL
*os << env_decl;
break;
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/remote_proxy_impl_cs.cpp b/TAO/TAO_IDL/be/be_visitor_operation/remote_proxy_impl_cs.cpp
index 969b8c081c1..9e0cefca478 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/remote_proxy_impl_cs.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/remote_proxy_impl_cs.cpp
@@ -103,7 +103,7 @@ be_visitor_operation_remote_proxy_impl_cs::visit_operation (be_operation *node)
// Generate the actual code for the stub. However, if any of the argument
// types is "native", we flag a MARSHAL exception.
// last argument - is always TAO_ENV_ARG_PARAMETER
*os << "{" << be_idt_nl;
/* This shall go away as soon as we drop the include_env switch
@@ -467,7 +467,7 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
// i.e. this is an optimization.
*os << "_tao_vfr.send_request (" << be_idt_nl
<< "&_tao_ri" << be_nl
- << "TAO_ENV_ARG_PARAMETER" << be_uidt_nl
+ << "ACE_ENV_ARG_PARAMETER" << be_uidt_nl
<< ");" << be_nl
<< "ACE_TRY_CHECK;" << be_nl;
@@ -493,7 +493,7 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
*os << be_nl
- << "_tao_call.start (TAO_ENV_SINGLE_ARG_PARAMETER);" << be_nl;
+ << "_tao_call.start (ACE_ENV_SINGLE_ARG_PARAMETER);" << be_nl;
// check if there is an exception
if (this->gen_check_interceptor_exception (bt) == -1)
{
@@ -507,7 +507,7 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
*os << be_nl
<< "_tao_call.prepare_header (" << be_idt << be_idt_nl
<< "ACE_static_cast (CORBA::Octet, _tao_response_flag)" << be_nl
- << "TAO_ENV_ARG_PARAMETER" << be_uidt_nl
+ << "ACE_ENV_ARG_PARAMETER" << be_uidt_nl
<< ");" << be_uidt_nl;
// check if there is an exception
@@ -569,7 +569,7 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
if (node->flags () == AST_Operation::OP_oneway)
{
// Oneway operation.
- *os << "_tao_call.invoke (TAO_ENV_SINGLE_ARG_PARAMETER);";
+ *os << "_tao_call.invoke (ACE_ENV_SINGLE_ARG_PARAMETER);";
}
else
{
@@ -578,11 +578,11 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
*os << "_tao_call.invoke (_tao_" << node->flat_name ()
<< "_exceptiondata, "
<< node->exceptions ()->length ()
- << " TAO_ENV_ARG_PARAMETER);";
+ << " ACE_ENV_ARG_PARAMETER);";
}
else
{
- *os << "_tao_call.invoke (0, 0 TAO_ENV_ARG_PARAMETER);";
+ *os << "_tao_call.invoke (0, 0 ACE_ENV_ARG_PARAMETER);";
}
}
@@ -626,7 +626,7 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
<< "_tao_ri.reply_status (_invoke_status);" << be_nl
<< "_tao_vfr.receive_other (" << be_idt_nl
<< "&_tao_ri" << be_nl
- << "TAO_ENV_ARG_PARAMETER" << be_uidt_nl
+ << "ACE_ENV_ARG_PARAMETER" << be_uidt_nl
<< ");" << be_nl
<< "ACE_TRY_CHECK;" << be_uidt_nl
<< ")" << be_nl
@@ -811,7 +811,7 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
<< "_tao_ri.reply_status (_invoke_status);" << be_nl
<< "_tao_vfr.receive_reply (" << be_idt_nl
<< "&_tao_ri" << be_nl
- << "TAO_ENV_ARG_PARAMETER" << be_uidt_nl
+ << "ACE_ENV_ARG_PARAMETER" << be_uidt_nl
<< ");" << be_nl;
}
else if (node->flags () == AST_Operation::OP_oneway)
@@ -821,7 +821,7 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
<< "_tao_ri.reply_status (_invoke_status);" << be_nl
<< "_tao_vfr.receive_other (" << be_idt_nl
<< "&_tao_ri" << be_nl
- << "TAO_ENV_ARG_PARAMETER" << be_uidt_nl
+ << "ACE_ENV_ARG_PARAMETER" << be_uidt_nl
<< ");" << be_nl;
}
@@ -844,7 +844,7 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
*os << "_tao_vfr.receive_exception (" << be_idt_nl
<< "&_tao_ri" << be_nl
- << "TAO_ENV_ARG_PARAMETER" << be_uidt_nl
+ << "ACE_ENV_ARG_PARAMETER" << be_uidt_nl
<< ");" << be_nl
<< "ACE_TRY_CHECK;" << be_nl;
@@ -854,7 +854,7 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
// caught exception.
*os << be_nl
<< "PortableInterceptor::ReplyStatus _tao_status =" << be_idt_nl
- << "_tao_ri.reply_status (TAO_ENV_SINGLE_ARG_PARAMETER);" << be_uidt_nl
+ << "_tao_ri.reply_status (ACE_ENV_SINGLE_ARG_PARAMETER);" << be_uidt_nl
<< "ACE_TRY_CHECK;" << be_nl;
*os << be_nl
@@ -887,7 +887,7 @@ be_visitor_operation_remote_proxy_impl_cs::gen_marshal_and_invoke (
// ClientRequestInfo object.
*os << be_nl
<< "PortableInterceptor::ReplyStatus _tao_status =" << be_idt_nl
- << "_tao_ri.reply_status (TAO_ENV_SINGLE_ARG_PARAMETER);" << be_uidt_nl;
+ << "_tao_ri.reply_status (ACE_ENV_SINGLE_ARG_PARAMETER);" << be_uidt_nl;
if (this->gen_check_exception (bt) == -1)
{
@@ -103,7 +103,7 @@ be_visitor_operation_remote_proxy_impl_cs::visit_operation (be_operation *node)
// Generate the actual code for the stub. However, if any of the argument
// types is "native", we flag a MARSHAL exception.
- // last argument - is always TAO_ENV_ARG_PARAMETER
+ // last argument - is always ACE_ENV_ARG_PARAMETER
*os << "{" << be_idt_nl;
/* This shall go away as soon as we drop the include_env switch